{% extends "wagtailadmin/reports/base_report.html" %}
{% load i18n wagtailadmin_tags %}

{% block results %}
    {% with object_list as page_types %}
        <div id="page-results">
            {% if page_types %}
                {% block listing %}
                    {% include "wagtailadmin/reports/listing/_list_page_types_usage.html" %}
                {% endblock listing %}
            {% else %}
                {% block no_results %}
                    <p>{% trans "No page types found." %}</p>
                {% endblock no_results %}
            {% endif %}
        </div>
    {% endwith %}
{% endblock results %}